#ifndef VSF_CHARCONV_H
#define VSF_CHARCONV_H

struct mystr;
struct vsf_session;

/* Supported charset for convertion */
#define VSFTP_CP_NONE    "NONE"
#define VSFTP_CP_UTF8    "UTF8"
#define VSFTP_CP_WIN1251 "WIN1251"
#define VSFTP_CP_KOI8R   "KOI8R"
#define VSFTP_CP_DOS     "DOS"
#define VSFTP_CP_1251    "1251"
#define VSFTP_CP_866     "866"
#define VSFTP_CP_878     "878"

#define VSFTP_C_NONE    0
#define VSFTP_C_UTF8    1
#define VSFTP_C_1251    2
#define VSFTP_C_878     3
#define VSFTP_C_866     4

#define UTF8_LOW_FIRST

struct codepage_map
{
  unsigned int char_code; // The first element is count bytes of char.
  int conv_code;          // The position in other tables
};

typedef struct codepage_map * map_ptr;

/* vsf_charset_name()
 * PURPOSE
 * Get charset name by code;
 * PARAMETERS
 * code         - Internal charset code
 * RETURNS
 * Charset name
 */
const char* vsf_charset_name(int code);

/* vsf_charset_init()
 * PURPOSE
 * Get internal charset code
 * PARAMETERS
 * p_str        - String value with code page
 * RETURNS
 * Internal charset code
 */
int vsf_charset_init(const char* p_str);

/* vsf_char_conv()
 * PURPOSE
 * Converting string via charsets
 * PARAMETERS
 * p_sess       - the current session object
 * p_str        - string for convertin
 * direction    - converting from host to remoute charsetr or otherwise
 */
void vsf_charset_conv(struct vsf_session* p_sess, struct mystr* p_str, int direction);

#endif

